==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/campaignequipment_001/CampaignEquipment.java <==

package net.datastream.schemas.mp_entities.campaignequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CAMPAIGNEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYLINESTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYWO" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="caller" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "campaignequipmentid",
    "surveylinestatus",
    "surveywo"
})
@XmlRootElement(name = "CampaignEquipment")
public class CampaignEquipment {

    @XmlElement(name = "CAMPAIGNEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CAMPAIGNEQUIPMENTID_Type campaignequipmentid;
    @XmlElement(name = "SURVEYLINESTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type surveylinestatus;
    @XmlElement(name = "SURVEYWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type surveywo;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "caller")
    protected String caller;

    /**
     * Obtient la valeur de la propriété campaignequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link CAMPAIGNEQUIPMENTID_Type }
     *     
     */
    public CAMPAIGNEQUIPMENTID_Type getCAMPAIGNEQUIPMENTID() {
        return campaignequipmentid;
    }

    /**
     * Définit la valeur de la propriété campaignequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link CAMPAIGNEQUIPMENTID_Type }
     *     
     */
    public void setCAMPAIGNEQUIPMENTID(CAMPAIGNEQUIPMENTID_Type value) {
        this.campaignequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété surveylinestatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSURVEYLINESTATUS() {
        return surveylinestatus;
    }

    /**
     * Définit la valeur de la propriété surveylinestatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSURVEYLINESTATUS(STATUS_Type value) {
        this.surveylinestatus = value;
    }

    /**
     * Obtient la valeur de la propriété surveywo.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getSURVEYWO() {
        return surveywo;
    }

    /**
     * Définit la valeur de la propriété surveywo.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setSURVEYWO(WOID_Type value) {
        this.surveywo = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété caller.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCaller() {
        return caller;
    }

    /**
     * Définit la valeur de la propriété caller.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCaller(String value) {
        this.caller = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/campaignequipment_001/CampaignEquipment.java <==

package net.datastream.schemas.mp_entities.campaignequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CAMPAIGNEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYLINESTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYWO" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="caller" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "campaignequipmentid",
    "surveylinestatus",
    "surveywo"
})
@XmlRootElement(name = "CampaignEquipment")
public class CampaignEquipment {

    @XmlElement(name = "CAMPAIGNEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CAMPAIGNEQUIPMENTID_Type campaignequipmentid;
    @XmlElement(name = "SURVEYLINESTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type surveylinestatus;
    @XmlElement(name = "SURVEYWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type surveywo;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "caller")
    protected String caller;

    /**
     * Gets the value of the campaignequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link CAMPAIGNEQUIPMENTID_Type }
     *     
     */
    public CAMPAIGNEQUIPMENTID_Type getCAMPAIGNEQUIPMENTID() {
        return campaignequipmentid;
    }

    /**
     * Sets the value of the campaignequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAMPAIGNEQUIPMENTID_Type }
     *     
     */
    public void setCAMPAIGNEQUIPMENTID(CAMPAIGNEQUIPMENTID_Type value) {
        this.campaignequipmentid = value;
    }

    /**
     * Gets the value of the surveylinestatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSURVEYLINESTATUS() {
        return surveylinestatus;
    }

    /**
     * Sets the value of the surveylinestatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSURVEYLINESTATUS(STATUS_Type value) {
        this.surveylinestatus = value;
    }

    /**
     * Gets the value of the surveywo property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getSURVEYWO() {
        return surveywo;
    }

    /**
     * Sets the value of the surveywo property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setSURVEYWO(WOID_Type value) {
        this.surveywo = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the caller property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCaller() {
        return caller;
    }

    /**
     * Sets the value of the caller property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCaller(String value) {
        this.caller = value;
    }

}
